from blue_objects.env import abcli_object_name
from abcli.logger import logger

logger.info(f"{abcli_object_name}: started.")

# --- your script here

logger.info("Hello World!")

# /script

logger.info(f"{abcli_object_name}: completed.")
